pub fn id_to_known_camera_control(id: u32) -> KnownCameraControlExpand description
Attempts to convert a u32 V4L2 Control ID into a KnownCameraControl
If the associated control is not found, this will return None (ColorEnable, Roll)
pub fn id_to_known_camera_control(id: u32) -> KnownCameraControlAttempts to convert a u32 V4L2 Control ID into a KnownCameraControl
If the associated control is not found, this will return None (ColorEnable, Roll)