pub fn known_camera_control_to_id(ctrl: KnownCameraControl) -> u32Expand description
Attempts to convert a KnownCameraControl into a V4L2 Control ID.
If the associated control is not found, this will return None (ColorEnable, Roll)
pub fn known_camera_control_to_id(ctrl: KnownCameraControl) -> u32Attempts to convert a KnownCameraControl into a V4L2 Control ID.
If the associated control is not found, this will return None (ColorEnable, Roll)