V4LCaptureDevice

Struct V4LCaptureDevice 

pub struct V4LCaptureDevice<'a> { /* private fields */ }
The backend struct that interfaces with V4L2. To see what this does, please see CaptureBackendTrait.

Quirks

Implementations

Source

impl<'a> V4LCaptureDevice<'a>

pub fn new( index: &CameraIndex, cam_fmt: RequestedFormat<'_>, ) -> Result<Self, NokhwaError>

Creates a new capture device using the V4L2 backend. Indexes are gives to devices by the OS, and usually numbered by order of discovery.

Errors

This function will error if the camera is currently busy or if V4L2 can’t read device information.

pub fn new_with( index: CameraIndex, width: u32, height: u32, fps: u32, fourcc: FrameFormat, ) -> Result<Self, NokhwaError>

👎Deprecated since 0.10.0:

please use new instead.

Create a new V4L2 Camera with desired settings. This may or may not work.

Errors

This function will error if the camera is currently busy or if V4L2 can’t read device information.

pub fn force_refresh_camera_format(&mut self) -> Result<(), NokhwaError>

Force refreshes the inner CameraFormat state.

Errors

If the internal representation in the driver is invalid, this will error.